@@ -37,7 +37,7 @@ def AmqpPublisherMiddleware(
 
             for event in self.event_service.event_list:
                 timer = self.statsd.get_timer(event.domain)
-                with timer.time(f"publish_amqp_event_time"):
+                with timer.time("publish_amqp_event_time"):
                     properties = {"content_type": "application/json"}
                     event_content = json.dumps(
                         {
